function OptionsOut=NLRopt(OptionsIn);
% function OptionsOut=NLRopt(OptionsIn);
%
% Purpose:
% Generates default options for the NLR routine.
% 
% Parameters:
% OptionsIn     - (optional)
%                 New values for the options.
%                 Default: []
%
% Returned Parameters:
% OptionsOut    - Values for the options. Default values
%                 are inserted if necessary.
%               
% Description:
%   OptionsOut(1) - Display results parameter.
%                   (Default:0).
%   OptionsOut(2) - Termination tolerance for X.
%                   (Default: 1e-4).
%   OptionsOut(3) - Termination tolerance on the residual
%                   sum of squares.
%                   (Default: 1e-2).
%   OptionsOut(4) - 1 = Compare Analytical and numerical derivative
%                   0 = Do not compare.
%                   (Default: 0
%   OptionsOut(5) - Maximum number of iterations.
%                   (Default: 10000)
%   OptionsOut(6) - Percent of change in parameters
%                   (Default: 1)
%   OptionsOut(7) - Start value Lambda   (used in Levenberg-Marquardt)
%                   (Default 1e-3)
%   OptionsOut(8) - Maximum value Lambda (used in Levenberg-Marquardt)
%                   (Default 1e-12)
%   OptionsOut(9) - Minimum value Lambda (used in Levenberg-Marquardt)
%                   (Default 1e-30)
%

if ( nargin < 1)
    OptionsIn = [];
end
OptionsIn               = OptionsIn(:);
SizeOpt                 = length(OptionsIn);
OptionsOut              = zeros(1,9);
OptionsOut(1:SizeOpt)   = OptionsIn(1:SizeOpt);
default_options         = [0,1e-4,1e-2,0,10000,1,1e-3,1e12,1e-30];
OptionsOut              = OptionsOut + (OptionsOut==0) .* default_options;
