function [r,B,dphit,dwt]=alignment(xa);

% input: xa is the original data set with only one sigle peak
% output: r is the number of iterations to get optimal phase and frequency position
%         B is the new data set after correction;
%         dphit is the value for phase correction;
%         dwt is the value for frequency correction.

% Original version by Han Witjes, this version by Ruifen Huo, Dec 2004.

[nr_spec,nr_points]=size(xa);
D=xa;
dphi=ones(nr_points,1);
dw=ones(nr_points,1);

r=0;
while r<1000

[PC]=pca(D,nr_points); 
X =[PC(:,1) PC(:,2) PC(:,3) PC(:,4)];
b=pinv(X)*D';

%%%%%% determine dphi and dw %%%%%%%%%%%%%%

dpha=-b(3,:)./b(1,:);
dphi=atan(dpha/pi);
dphi=dphi';
dphit=dphi;

dw=b(2,:)./b(1,:);
dw=dw';
dwt=dw;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% correct spectra with dphi en dw %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%% D+dphi ==> A %%%%%%%%%%%%%

A=hilbert(D');

C=zeros(size(D'));
for k=1:nr_spec
  C(:,k)=cos(-dphi(k)*pi)*real(A(:,k)) - sin(-dphi(k)*pi)*imag(A(:,k));
end;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

A=C';
clear B C


%%%%%%%%%%%%% A+dw ==> B%%%%%%%%%%%%%%%

B=zeros(size(A));
C=zeros(size(A));
E=zeros(size(A));
F=zeros(size(A));
H=zeros(size(A));

phaseshift = dw - floor(dw);
factor     = zeros(nr_spec,1);


for k=1:nr_spec
  B(k,:)=ifft(A(k,:));
end;

for k=1:nr_spec
  for l=1:nr_points
    C(k,l)=B(k,l)*exp(j*2*pi*l*dw(k)/nr_points);
  end;
end;


for k=1:nr_spec
  E(k,1:nr_points/2) = C(k,1:nr_points/2)* exp(pi*i*phaseshift(k));
  E(k,nr_points/2+1:nr_points) = C(k,nr_points/2+1:nr_points) * exp(-pi*i*phaseshift(k));
end;

for k=1:nr_spec
  F(k,:) = fft(E(k,:));
end;

for k=1:nr_spec
  factor(k)=1/(cos(2*pi*-dw(k)/nr_points));
  H(k,:)=factor(k)*(cos(-phaseshift(k)*pi)*real(F(k,:)) - sin(-phaseshift(k)*pi)*imag(F(k,:)));
end;

B=H;

clear C E F H;

for k=1:nr_spec
  if abs(dphi(k))>=0.0000001
    dphi(k)=0;
  else
    dphi(k)=1;
  end
  if abs(dw(k))>=0.0000000001
    dw(k)=0;
  else
    dw(k)=1;
  end
end
D=B;
r=r+1;
if all(dphi) & all(dw)
  break
end

end

