function [I,sigma_noise,x_baseline,xcorr]=baseline_reco(x,n,N,m);

% recognise baseline: (max(y)-min(y))<n*std(noise).
% n is a constant value (e.g n=12) and N(e.g N=81) is the size of the window;
% m is the centre point for smoothing window.(m=20)
% calculate the min std(noise)of differents windows;

% Reference: 
% S.Golotvin and A. Williams, Improved baseline recognition and
% modelling of FT NMR spectra, J. Magn. Reson. 146, 122-125 (2000)

[r,c]=size(x);
a=(N-1)/2;
sigmaa=zeros(1,c-2*a-1);
xa=zeros(size(x));
x_baseline=zeros(size(x));
% calculate the smoothed spectrum

for i=m+1:c-m
  xa(i)=sum(x(i-m:i+m))/(2*m+1);
end
 
for i=a+1:c-a
 sigmaa(i-a)=std(x(i-a:i+a));
end
sigma_noise=min(sigmaa);

for i=a+1:c-a
  y=x(i-a:i+a);
  detY=max(y)-min(y);
  if detY<n*sigma_noise
    x_baseline(i)=xa(i);
  end
end

% connect the baseline fragments by straight line; the straignht line is
% calculated by the end points of the neibourgh fragments;

I=find(x_baseline);

for i=1:size(I,2)-1
  if I(i+1)-I(i)>1
    yb=x_baseline([I(i) I(i+1)])';
    xb=[I(i) 1;I(i+1) 1];
    [Q, R]=qr(xb,0);
    b = R\(Q'*yb);
    xc=I(i):I(i+1);
    yc=b(1)*xc+b(2);
    x_baseline(I(i):I(i+1))=yc;
  end
end
x_baseline(1:m)=x_baseline(m+1:2*m);
x_baseline(c-m+1:c)=x_baseline(c-2*m:c-m-1);
xcorr=x-x_baseline;
xcorr(1:a+10)=xcorr(a+11:2*a+20);
xcorr(c-a-9:c)=xcorr(a+11:2*a+20);



