% File: demo.m
%
% Demonstration of the analysis of simulated DOSY data
% To get more information on a function foo, type "help foo".
%
% 1. Generate and load the simulated data;
cd simulated_data           % go to the directory simulated_data;
[I_shift1,K]=shift_data1;   % simulate;
plot(I_shift1');
title('a plot of the simulated data set');
cd ../                      % go back to home directory trial;

% 2. Preprocessing of DOSY NMR data;
close all                   % close all figure windows;
disp('preprocessing of DOSY NMR data');
% a. baseline correction
n=7; N=81;                  % these parameters can vary;
[basecorrect_x]=spec_baseline(I_shift1,n,N,20);
plot(basecorrect_x');       % plot the data with baseline correction;

% b. correct for peak and phase shifts;
% Note: (area2-area1) must be odd number;
area1=50; area2=361;        % define a single peak as a reference; 
barea=[40:80];              % barea is an area containing only noise;
[correctx]=fiddle(basecorrect_x,area1,area2,barea);
plot(correctx');
title('a plot of the corrected data set');

% 3. resolve the DOSY data;
close all
% a. find the pure variables by OPA;
%    Input parameters:
% ncom is the estimated number of components;
ncom=3;   
% range1 contains frequency ranges that consist of signals;
range1=[200 300; 420 560; 700 780];
% the threshold of the mean of the variable that is high enough 
% for normalisation. this is not an easy choice. You need to try 
% more t values (15% of the highest peak in this case);
t=30; 
% The columns of matrix c0 contain the pure decay profiles, 
% normc0 contains normalised pure decays that can be used to see if two
% profiles actually correspond to the same compound.
[c0,normc0]=opa(correctx,ncom,range1,t);

% b. Resolve the pure spectra and decay profiles by MCR_NLR;
close all
% variable 'order' contains the orders used in polynomial fitting
order=[1 1 1]; 
% maximum number of iterations
maxit = 100;
% cutoff is a variable for the decay profiles: values smaller than the cutoff are
% not taken into account in the initialisation of the NLR.
cutoff = 0.01
close all 
[c,s,covresid,covresid1,resi]=mymcr_nlr(correctx,maxit,normc0,K,order,cutoff);

% If you want to comapre the results from classical MCR, where only non-negativity 
% constraits are applied, run the function dosy_mcr
[cmcr,smcr]=dosy_mcr(correctx,c0,20);

% End of demo.





