function [c,s]=dosy_mcr(x,c0,ittol);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%% function [c,s,covresid,covresid1]=dosy_mcr(x,c0,ittol);
%%% Use classical Multivatiate curve resolution(MCR) to resolve DOSY data;
%%% Only non-negativity constrained is used.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Input parameters:

%% x is a 2D NMRDOSY data set, and can be decomposed as x=c*s.

%% ittol is the the convergance criteria for MCR. 
%% ittol < 1, convergance tolerance [e.g. 1e-4], and
%% ittol >=1, max number of iterations.

%% c0 is the initial guess of the decay profiles matrix;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Output parameters:

%% covresid: covariance matrix of residuals (whole matrix);

%% covresid1: covariance matrix of residuals with the diagonal elements left out;

%% resi: Sum of residuals of each iteration;

%% c: resolved pure decay profiles; s: resolved pure spectra.

%% Writen by Ruifen Huo 7th Dec. 2005.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Resolve the pure spectra and pure decay profile;
c=c0; ka=size(c0,2);
[m,n]=size(x);
sclc=1:m;scls=1:n;
nnstol=max(size(x))*norm(x,1)*eps;
opts=optimset('lsqnonneg');
opts=optimset(opts,'Display','off');
for ii=1:length(scls)
  s0(:,ii)=lsqnonneg(c,x(:,ii),[],opts);
end   
for i1=1:size(c0,2)
    s0(i1,:)=s0(i1,:)/norm(s0(i1,:)');
end

if ittol<1
  itmax = 1e6; itmin = ittol;
  if ittol<1e-6
    itmin = 1e-6;
  end
else
  itmax = ittol; itmin = 1e-8;
  if itmax>1e6
    itmax = 1e6;
  end
end
s=s0;
it = 0;
while it<itmax
  if it>1
    for ii=1:length(sclc)
    c(ii,:) = lsqnonneg(s',x(ii,:)',c(ii,:)',opts)';  
    end
  else
    for ii=1:size(x,1)
    c(ii,:)=lsqnonneg(s',x(ii,:)',[],opts)';
    end
  end

 for ii=1:length(scls)
    s(:,ii)=lsqnonneg(c,x(:,ii),s(:,ii),opts);
  end   

 % for i1=1:size(c0,2)
 %   s(i1,:)=s(i1,:)/norm(s(i1,:)');
 %end
  
  it     = it+1; garb = it;
  if (ittol<1)&((it/2-round(it/2))==0)
    resc = 0; ress = 0;
    for ii=1:ka
      resc = resc+norm(c0(:,ii));
      ress = ress+norm(s0(ii,:));
    end
    ress = sqrt(sum(sum((s'-s0').^2)')/ka/ress);
    resc = sqrt(sum(sum((c-c0).^2)')/ka/resc);
    if (ress<itmin)&(resc<itmin)
      it = itmax+1; 
    else
      c0 = c;
      s0 = s;
    end
  end
end

disp('iteration=');disp(garb);
residual=sum(sum((x-c*s).^2));
disp('residual');disp(residual);
lof=sqrt(residual/sum(sum(x.^2)))*100;
disp('lack of fit');disp(lof);
figure;
for i=1:size(c0,2)
subplot(size(c0,2),1,i);plot(s(i,:));
end
subplot(size(c0,2),1,1);title('Resolved pure spectra');

figure 
plot(c);
title('Resolved pure decay profiles');


% end of dosy_mcr.m.