function [correctx]=fiddle(x,area1,area2,barea);

% function [correctx]=fiddle(x,area1,area2,barea);
% combine reference deconvolution and peak shift method to correct
% the artefacts of the spetra;

% x is the matrix being corrected and barea is used as the reference 
% to correct peak and phase shift;

% area1 and area2 are the start and end indices of the reference peak, respectively;  

% barea is an area with only noise, e.g. barea=[850:900];
% output: correctx is the corrected 2D data.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Written by Ruifen Huo (07/11/2002)

[m,n]=size(x);

B=x;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% eliminate the peaks of the spectra so that only the reference peak is left
% with the noise background;

for i=1:m
 B(i,[1:area1])=B(i,area1)+std(B(i,barea)).*(0.91*randn(size(B(i,[1:area1]))));
 B(i,[area2:end])=B(i,area2)+std(B(i,barea)).*(0.91*randn(size(B(i,[area2:end]))));
end

% correction of the reference peak;
range1=[area1 area2];

[correct_B]=correc_peak_phase(B,range1);

% correction of the whole spectrum (FIDDLE)
for i=1:m
  iffA(i,:)=ifft(x(i,:));
  iffB(i,:)=ifft(B(i,:));
  iffC(i,:)=ifft(correct_B(i,:));
end

iffcorrectx=iffA.*(iffC./(iffB));

for i=1:m
correctx(i,:)=real(fft(iffcorrectx(i,:)));
end


