function [c,s,covresid,covresid1,resi]=mymcr_nlr(x,ittol,c0,K,order,cutoff);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%% function [c,s,covresid,covresid1,resi]=mymcr_nlr(x,ittol,c0,K,order,cutoff);
%%% combine non-linear regression with MCR to resolve DOSY data;
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Input parameters:

%% x is a 2D NMRDOSY data;

%% ittol is the iteration of MCR. A large number can be chosen (say ittol=100). 
%% The iteration will be stopped if the sum of residuals is very low.

%% c0 is the initial guess of the decay profiles matrix;

%% K is the g^2 for fitting;

%% order is a vector containing the orders used in polynomial fitting for
%% different components. Normal is 1, e.g. order=[1 1 1 1];

%% cutoff is a variable for the decay profiles: values smaller than the cutoff are
%% not taken into account in the initialisation of the NLR.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Output parameters:

%% covresid: covariance matrix of residuals (whole matrix);

%% covresid1: covariance matrix of residuals with the diagonal elements left out;

%% resi: Sum of residuals of each iteration;

%% c: resolved pure decay profiles; s: resolved pure spectra.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

it=0;c=c0;x1=x;
[m,n]=size(x);
sclc=1:m;scls=1:n;
nnstol=max(size(x))*norm(x,1)*eps;
opts=optimset('lsqnonneg');
opts=optimset(opts,'Display','off');
for ii=1:length(scls)
  s0(:,ii)=lsqnonneg(c,x(:,ii),[],opts);
  end   
s=s0;
for i1=1:size(c0,2)
    s(i1,:)=s(i1,:)/norm(s(i1,:)');
end

ncomp = size(c0, 2);
object = zeros(1, ncomp);
for ii = 1:ncomp
  for it = 1:m
    if c0(it,ii) > cutoff 
      object(ii) = object(ii) + 1;
    end
  end
end

it = 0;
while it<ittol
  for ii=1:size(x,1)
    c(ii,:)=lsqnonneg(s',x(ii,:)',[],opts)';
  end

  c1=zeros(size(c));
 
  for i=1:size(c0,2)
    logp1(i,1:order(i)+1)=polyfit(K(1:object(i)),log(c(1:object(i),i)),order(i));
    logp1(i,order(i)+1)=exp(logp1(i,order(i)+1))*1e-5;
    logp1_best(:,i)=nlr(K,c(:,i),'model_Dosy',logp1(i,:));
    c1(:,i)=model_Dosy(K,logp1_best(:,i));
  end
 
  c=c1;
 
  for ii=1:length(scls)
    s(:,ii)=lsqnonneg(c,x(:,ii),[],opts);
  end   

  for i1=1:size(c0,2)
    s(i1,:)=s(i1,:)/norm(s(i1,:)');
  end
   
  
  re=x-c*s;
  it=it+1;
  resi(it)=sum(sum(re.^2));

  if it>1
    if resi(it-1)-resi(it)<1e-4
      break
    end
  end
end
  
residual=sum(sum((x-c*s).^2));
disp('residual');disp(residual);
lof=sqrt(residual/sum(sum(x.^2)))*100;
disp('lack of fit');disp(lof);
figure
for i=1:size(c0,2)
subplot(size(c0,2),1,i);plot(scls,s(i,:));
end
title('Resolved pure spectra');
figure 
plot(K,c);
title('Resolved pure decay profiles');

% Diagnostic: covariance of residuals matrix;
resid=x-c*s;
covresid=resid*resid';
figure;plot(covresid);
title('CMR plot');

% covariance residual matrix left out diagonal elements;
covresid1(1,:)=covresid(1,2:end);
K2(:,1)=K(2:end);
for i=2:size(x,1)-1
covresid1(i,:)=covresid(i,[1:i-1 i+1:end]);
K2(:,i)=K([1:i-1 i+1:end]);
end
covresid1(size(x,1),:)=covresid(end,1:end-1);
K2(:,size(x,1))=K(1:end-1);
figure;
plot(covresid1'); 
title('CMR plot leaving out the diagonal elements');
