function [C,K,I,spectra]=dosy_data;

% function [C,K,I,spectra]=dosy_data;
% to simulate a DOSY data set having four similar diffusion components;
% the diffusion coeffisions are 8.00e-8,5e-7,1.00e-7,2e-7, respectively;
% I is the simulated DOSY NMR data;
% K = the area of the gradient pulse in cm-1
% spectra = a matrix containing the four true spectra;
% C = a matrix containing the four true decay profiles. 
% Written by Ruifen Huo 

close all
K=19321e+4:(64e+4-19321e+4)/31:64e+4;

K=fliplr(K);K=K';
[x,spectra]=seperate_spec;

spectra(1,:)=spectra(1,:)-0.505;
spectra(2,:)=spectra(2,:)-1.0342;
spectra(3,:)=spectra(3,:)-0.5038;
spectra(4,:)=spectra(4,:)-0.7782;

D=[8.00e-8,5e-7,1.00e-7,2e-7];
for j=1:(size(D',1))
C(:,j)=exp(-D(j).*(.1-.005/3).*K);
end

I=C*spectra;
I=I+0.025*randn(size(I));

% plot a decaying curve
figure
x=0:0.01:9.99;
K1=0.0064:(1.9321-0.0064)/31:1.9321;
[X,Y]=meshgrid(x,K1);
for i=1:20;
plot3(x,Y(i,:),I(i,:));
hold on
end
set(gca,'XDIR','reverse');
xlabel('Chemical Shift(ppm)');
ylabel('Gradient levels');
zlabel('intensity');
title('Fig.1 Decaying NMR Data with Gradient');






